# Changelog

## [0.0.13a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a1) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.12...0.0.13a1)

**Breaking changes:**

- MessageBusClient compat [\#60](https://github.com/OpenVoiceOS/OVOS-workshop/issues/60)

**Fixed bugs:**

- fix/abstract app init [\#130](https://github.com/OpenVoiceOS/OVOS-workshop/pull/130) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
